@@ -14,7 +14,9 @@ def make_info(document):
 def predictionsUnique(saved_model_folder,json,labels_tab):
     predictions_data = getDataForUniquePrediction(json,labels_tab)
 
-    model = torch.load(os.path.join(saved_model_folder, "saved_model.pt"))
+    torchMode = "cuda" if torch.cuda.is_available() else "cpu"
+
+    model = torch.load(os.path.join(saved_model_folder, "saved_model.pt"), torchMode)
 
     y_preds = model(predictions_data).max(dim=1)[1].cpu().numpy()
 
